@@ -1,30 +1,31 @@
-"""Conversion functions for dictionaries"""
+"""Dictionary converters"""
+from olutils.collection.functions import identity
 
 
-def basedict(obj, leaf_conv=lambda x: x):
-    """Return base dict from dict-like object (recursive)
+def basedict(__object, /, leafconv=identity):
+    """Return base dict from object (recursive)
 
     Args:
-        obj (dict-like)     : object to recursively convert
-        leaf_conv (callable): function to convert leafs (not dict values)
+        __object (dict)     : dict-like object to recursively convert
+        leafconv (callable) : function to convert leaves (not dict values)
 
     Return:
         (dict)
     """
-    if isinstance(obj, dict):
+    if isinstance(__object, dict):
         return {
-            key: basedict(value, leaf_conv=leaf_conv)
-            for key, value in obj.items()
+            key: basedict(value, leafconv=leafconv)
+            for key, value in __object.items()
         }
-    return leaf_conv(obj)
+    return leafconv(__object)
 
 
-def dict2str(obj, bullets="#*>-", indent="\t", prefix="",
+def dict2str(__object, /, *, bullets="#*>-", indent="\t", prefix="",
              keyconv=str, leafconv=str):
     """Convert dict to pretty formatted string
 
     Args:
-        obj (dict)      : dictionary to format to string
+        __object (dict) : dictionary to format to string
         bullets (str)   : list of bullets to use for dict-ladders
         indent (str)    : indent to add when going to next dict-ladder
         prefix (str)    : prefix before each row in string
@@ -32,10 +33,10 @@ def dict2str(obj, bullets="#*>-", indent="\t", prefix="",
         leafconv (func) : dict-leaf string converter
 
     Return:
-        (str) pretty representation of obj
+        (str) pretty representation of __object
     """
-    if not isinstance(obj, dict):
-        return leafconv(obj)
+    if not isinstance(__object, dict):
+        return leafconv(__object)
 
     bullet = bullets[0] if bullets else ""
     exbullet = "" if bullet in ["", " "] else (bullet + " ")
@@ -43,17 +44,21 @@ def dict2str(obj, bullets="#*>-", indent="\t", prefix="",
 
     string = ""
     try:
-        key_maxsize = max(len(keyconv(key)) for key in obj.keys())
+        key_maxsize = max(len(keyconv(key)) for key in __object.keys())
     except ValueError:
         return "<empty dict>"
-    for key, value in obj.items():
+    for key, value in __object.items():
         if string:
             string += "\n"
         if isinstance(value, dict):
             string += prefix + exbullet + keyconv(key).ljust(key_maxsize) + ":"
             value_str = dict2str(
-                value, bullets=nbullets, indent=indent, prefix=prefix+indent,
-                leafconv=leafconv, keyconv=keyconv
+                value,
+                bullets=nbullets,
+                indent=indent,
+                prefix=prefix+indent,
+                leafconv=leafconv,
+                keyconv=keyconv,
             )
             if value:
                 string += "\n" + value_str
