@@ -1,4 +1,4 @@
-"""Provide functions to store / load objects in / from files"""
+"""Functions to load and save objects"""
 
 from .common import DFT_EOL
 from .csv import read_csv, write_csv
